import OCP.XBRepMesh
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
__all__  = [
"XBRepMesh"
]
class XBRepMesh():
    def __init__(self) -> None: ...
    pass
