import OCP
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
__all__  = [
"AIS",
"APIHeaderSection",
"Adaptor2d",
"Adaptor3d",
"AdvApp2Var",
"AdvApprox",
"AppBlend",
"AppCont",
"AppDef",
"AppParCurves",
"AppStd",
"AppStdL",
"Approx",
"Aspect",
"BOPAlgo",
"BOPDS",
"BOPTools",
"BRep",
"BRepAdaptor",
"BRepAlgo",
"BRepAlgoAPI",
"BRepApprox",
"BRepBlend",
"BRepBndLib",
"BRepBuilderAPI",
"BRepCheck",
"BRepClass",
"BRepClass3d",
"BRepExtrema",
"BRepFeat",
"BRepFill",
"BRepFilletAPI",
"BRepGProp",
"BRepIntCurveSurface",
"BRepLProp",
"BRepLib",
"BRepMAT2d",
"BRepMesh",
"BRepOffset",
"BRepOffsetAPI",
"BRepPrim",
"BRepPrimAPI",
"BRepProj",
"BRepSweep",
"BRepToIGES",
"BRepToIGESBRep",
"BRepTools",
"BRepTopAdaptor",
"BSplCLib",
"BSplSLib",
"BVH",
"BiTgte",
"BinDrivers",
"BinLDrivers",
"BinMDF",
"BinMDataStd",
"BinMDataXtd",
"BinMDocStd",
"BinMFunction",
"BinMNaming",
"BinObjMgt",
"BinTObjDrivers",
"BinTools",
"BinXCAFDrivers",
"Bisector",
"Blend",
"BlendFunc",
"Bnd",
"BndLib",
"CDF",
"CDM",
"CPnts",
"CSLib",
"ChFi2d",
"ChFi3d",
"ChFiDS",
"Contap",
"Convert",
"DE",
"Draft",
"DsgPrs",
"ElCLib",
"ElSLib",
"Expr",
"ExprIntrp",
"Extrema",
"FEmTool",
"FSD",
"FairCurve",
"FilletSurf",
"Font",
"GC",
"GCE2d",
"GCPnts",
"GProp",
"GccAna",
"GccEnt",
"GccInt",
"Geom",
"Geom2d",
"Geom2dAPI",
"Geom2dAdaptor",
"Geom2dConvert",
"Geom2dEvaluator",
"Geom2dGcc",
"Geom2dHatch",
"Geom2dInt",
"Geom2dLProp",
"Geom2dToIGES",
"GeomAPI",
"GeomAbs",
"GeomAdaptor",
"GeomConvert",
"GeomEvaluator",
"GeomFill",
"GeomInt",
"GeomLProp",
"GeomLib",
"GeomPlate",
"GeomProjLib",
"GeomToIGES",
"GeomToStep",
"GeomTools",
"Graphic3d",
"HLRAlgo",
"HLRAppli",
"HLRBRep",
"HLRTopoBRep",
"Hatch",
"HatchGen",
"Hermit",
"IFGraph",
"IFSelect",
"IGESAppli",
"IGESBasic",
"IGESCAFControl",
"IGESControl",
"IGESConvGeom",
"IGESData",
"IGESDefs",
"IGESDimen",
"IGESDraw",
"IGESFile",
"IGESGeom",
"IGESGraph",
"IGESSelect",
"IGESSolid",
"IGESToBRep",
"IMeshData",
"IMeshTools",
"IVtk",
"IVtkOCC",
"IVtkTools",
"IVtkVTK",
"Image",
"IntAna",
"IntAna2d",
"IntCurve",
"IntCurveSurface",
"IntCurvesFace",
"IntImp",
"IntImpParGen",
"IntPatch",
"IntPolyh",
"IntRes2d",
"IntStart",
"IntSurf",
"IntTools",
"Interface",
"InterfaceGraphic",
"Intf",
"Intrv",
"LDOM",
"LProp",
"LProp3d",
"Law",
"LocOpe",
"LocalAnalysis",
"MAT",
"MAT2d",
"MeshVS",
"Message",
"NCollection",
"NIS",
"NLPlate",
"OSD",
"OpenGl",
"PCDM",
"PLib",
"Plate",
"Plugin",
"Poly",
"Precision",
"ProjLib",
"Prs3d",
"PrsMgr",
"Quantity",
"RWGltf",
"RWMesh",
"RWStepAP203",
"RWStepAP214",
"RWStepAP242",
"RWStepBasic",
"RWStepDimTol",
"RWStepElement",
"RWStepFEA",
"RWStepGeom",
"RWStepRepr",
"RWStepShape",
"RWStepVisual",
"RWStl",
"Resource",
"STEPCAFControl",
"STEPConstruct",
"STEPControl",
"STEPEdit",
"STEPSelections",
"Select3D",
"SelectBasics",
"SelectMgr",
"ShapeAlgo",
"ShapeAnalysis",
"ShapeBuild",
"ShapeConstruct",
"ShapeCustom",
"ShapeExtend",
"ShapeFix",
"ShapeProcess",
"ShapeProcessAPI",
"ShapeUpgrade",
"Standard",
"StdDrivers",
"StdFail",
"StdLDrivers",
"StdLPersistent",
"StdObjMgt",
"StdObject",
"StdPersistent",
"StdPrs",
"StdSelect",
"StdStorage",
"StepAP203",
"StepAP209",
"StepAP214",
"StepAP242",
"StepBasic",
"StepData",
"StepDimTol",
"StepElement",
"StepFEA",
"StepGeom",
"StepRepr",
"StepShape",
"StepToGeom",
"StepToTopoDS",
"StepVisual",
"StlAPI",
"Storage",
"Sweep",
"TColGeom",
"TColGeom2d",
"TColStd",
"TColgp",
"TCollection",
"TDF",
"TDataStd",
"TDataXtd",
"TDocStd",
"TFunction",
"TNaming",
"TObj",
"TPrsStd",
"TShort",
"TopAbs",
"TopBas",
"TopClass",
"TopCnx",
"TopExp",
"TopLoc",
"TopOpeBRep",
"TopOpeBRepBuild",
"TopOpeBRepDS",
"TopOpeBRepTool",
"TopTools",
"TopTrans",
"TopoDS",
"TopoDSToStep",
"Transfer",
"UTL",
"Units",
"UnitsAPI",
"UnitsMethods",
"V3d",
"Voxel",
"Vrml",
"VrmlAPI",
"XBRepMesh",
"XCAFApp",
"XCAFDimTolObjects",
"XCAFDoc",
"XCAFNoteObjects",
"XCAFPrs",
"XCAFView",
"XSControl",
"XmlDrivers",
"XmlLDrivers",
"XmlMDF",
"XmlMDataStd",
"XmlMDataXtd",
"XmlMDocStd",
"XmlMFunction",
"XmlMNaming",
"XmlObjMgt",
"XmlTObjDrivers",
"XmlXCAFDrivers",
"Xw",
"gce",
"gp",
"math",
"__version__"
]
__version__ = '7.9.3.1'
