// pybind 11 related includes
#include <pybind11/pybind11.h>
#include <pybind11/stl.h>

namespace py = pybind11;

// user-defined pre
#include "OCP_specific.inc"

// forward declaration of the register_* functions

void register_NCollection_enums(py::module&);
void register_AIS_enums(py::module&);
void register_Standard_enums(py::module&);
void register_gp_enums(py::module&);
void register_math_enums(py::module&);
void register_BVH_enums(py::module&);
void register_TColgp_enums(py::module&);
void register_OSD_enums(py::module&);
void register_Quantity_enums(py::module&);
void register_Storage_enums(py::module&);
void register_FSD_enums(py::module&);
void register_TCollection_enums(py::module&);
void register_TColStd_enums(py::module&);
void register_Message_enums(py::module&);
void register_StdFail_enums(py::module&);
void register_TShort_enums(py::module&);
void register_Plugin_enums(py::module&);
void register_Resource_enums(py::module&);
void register_Units_enums(py::module&);
void register_UnitsAPI_enums(py::module&);
void register_TopLoc_enums(py::module&);
void register_Poly_enums(py::module&);
void register_Precision_enums(py::module&);
void register_Expr_enums(py::module&);
void register_ExprIntrp_enums(py::module&);
void register_GeomAbs_enums(py::module&);
void register_PLib_enums(py::module&);
void register_BSplCLib_enums(py::module&);
void register_BSplSLib_enums(py::module&);
void register_Bnd_enums(py::module&);
void register_CSLib_enums(py::module&);
void register_Convert_enums(py::module&);
void register_ElCLib_enums(py::module&);
void register_ElSLib_enums(py::module&);
void register_Adaptor2d_enums(py::module&);
void register_Geom2d_enums(py::module&);
void register_Geom2dAdaptor_enums(py::module&);
void register_Geom2dEvaluator_enums(py::module&);
void register_LProp_enums(py::module&);
void register_Geom2dLProp_enums(py::module&);
void register_TColGeom2d_enums(py::module&);
void register_Adaptor3d_enums(py::module&);
void register_AdvApprox_enums(py::module&);
void register_GProp_enums(py::module&);
void register_Geom_enums(py::module&);
void register_GeomAdaptor_enums(py::module&);
void register_GeomEvaluator_enums(py::module&);
void register_GeomLProp_enums(py::module&);
void register_LProp3d_enums(py::module&);
void register_TColGeom_enums(py::module&);
void register_TopAbs_enums(py::module&);
void register_AdvApp2Var_enums(py::module&);
void register_AppCont_enums(py::module&);
void register_AppParCurves_enums(py::module&);
void register_Approx_enums(py::module&);
void register_AppDef_enums(py::module&);
void register_BndLib_enums(py::module&);
void register_CPnts_enums(py::module&);
void register_Extrema_enums(py::module&);
void register_FEmTool_enums(py::module&);
void register_GC_enums(py::module&);
void register_GCE2d_enums(py::module&);
void register_GCPnts_enums(py::module&);
void register_Geom2dConvert_enums(py::module&);
void register_GeomConvert_enums(py::module&);
void register_GeomLib_enums(py::module&);
void register_GeomProjLib_enums(py::module&);
void register_GeomTools_enums(py::module&);
void register_Hermit_enums(py::module&);
void register_IntAna_enums(py::module&);
void register_IntAna2d_enums(py::module&);
void register_ProjLib_enums(py::module&);
void register_gce_enums(py::module&);
void register_TopoDS_enums(py::module&);
void register_BRep_enums(py::module&);
void register_BRepAdaptor_enums(py::module&);
void register_BRepLProp_enums(py::module&);
void register_TopTools_enums(py::module&);
void register_BRepTools_enums(py::module&);
void register_BinTools_enums(py::module&);
void register_TopExp_enums(py::module&);
void register_AppBlend_enums(py::module&);
void register_FairCurve_enums(py::module&);
void register_GccAna_enums(py::module&);
void register_GccEnt_enums(py::module&);
void register_GccInt_enums(py::module&);
void register_Geom2dAPI_enums(py::module&);
void register_Geom2dGcc_enums(py::module&);
void register_IntRes2d_enums(py::module&);
void register_Intf_enums(py::module&);
void register_Geom2dInt_enums(py::module&);
void register_Geom2dHatch_enums(py::module&);
void register_GeomAPI_enums(py::module&);
void register_GeomFill_enums(py::module&);
void register_GeomInt_enums(py::module&);
void register_GeomPlate_enums(py::module&);
void register_Hatch_enums(py::module&);
void register_HatchGen_enums(py::module&);
void register_IntCurve_enums(py::module&);
void register_IntCurveSurface_enums(py::module&);
void register_IntImp_enums(py::module&);
void register_IntImpParGen_enums(py::module&);
void register_IntPatch_enums(py::module&);
void register_IntPolyh_enums(py::module&);
void register_IntStart_enums(py::module&);
void register_IntSurf_enums(py::module&);
void register_Law_enums(py::module&);
void register_LocalAnalysis_enums(py::module&);
void register_NLPlate_enums(py::module&);
void register_Plate_enums(py::module&);
void register_TopClass_enums(py::module&);
void register_TopTrans_enums(py::module&);
void register_BRepApprox_enums(py::module&);
void register_BRepBndLib_enums(py::module&);
void register_BRepBuilderAPI_enums(py::module&);
void register_BRepCheck_enums(py::module&);
void register_BRepClass_enums(py::module&);
void register_BRepClass3d_enums(py::module&);
void register_BRepExtrema_enums(py::module&);
void register_BRepGProp_enums(py::module&);
void register_BRepIntCurveSurface_enums(py::module&);
void register_BRepLib_enums(py::module&);
void register_BRepMAT2d_enums(py::module&);
void register_BRepTopAdaptor_enums(py::module&);
void register_Bisector_enums(py::module&);
void register_IntCurvesFace_enums(py::module&);
void register_MAT_enums(py::module&);
void register_MAT2d_enums(py::module&);
void register_BRepPrim_enums(py::module&);
void register_BRepPrimAPI_enums(py::module&);
void register_BRepSweep_enums(py::module&);
void register_Sweep_enums(py::module&);
void register_ShapeAlgo_enums(py::module&);
void register_ShapeAnalysis_enums(py::module&);
void register_ShapeBuild_enums(py::module&);
void register_ShapeConstruct_enums(py::module&);
void register_ShapeCustom_enums(py::module&);
void register_ShapeExtend_enums(py::module&);
void register_ShapeFix_enums(py::module&);
void register_ShapeProcess_enums(py::module&);
void register_ShapeProcessAPI_enums(py::module&);
void register_ShapeUpgrade_enums(py::module&);
void register_Contap_enums(py::module&);
void register_HLRAlgo_enums(py::module&);
void register_HLRAppli_enums(py::module&);
void register_HLRBRep_enums(py::module&);
void register_HLRTopoBRep_enums(py::module&);
void register_Intrv_enums(py::module&);
void register_TopBas_enums(py::module&);
void register_TopCnx_enums(py::module&);
void register_BRepMesh_enums(py::module&);
void register_XBRepMesh_enums(py::module&);
void register_BOPAlgo_enums(py::module&);
void register_BOPDS_enums(py::module&);
void register_BOPTools_enums(py::module&);
void register_BRepAlgoAPI_enums(py::module&);
void register_IntTools_enums(py::module&);
void register_BRepAlgo_enums(py::module&);
void register_BRepFill_enums(py::module&);
void register_BRepProj_enums(py::module&);
void register_TopOpeBRep_enums(py::module&);
void register_TopOpeBRepBuild_enums(py::module&);
void register_TopOpeBRepDS_enums(py::module&);
void register_TopOpeBRepTool_enums(py::module&);
void register_BRepFeat_enums(py::module&);
void register_LocOpe_enums(py::module&);
void register_Blend_enums(py::module&);
void register_BRepBlend_enums(py::module&);
void register_BRepFilletAPI_enums(py::module&);
void register_BlendFunc_enums(py::module&);
void register_ChFi2d_enums(py::module&);
void register_ChFi3d_enums(py::module&);
void register_ChFiDS_enums(py::module&);
void register_FilletSurf_enums(py::module&);
void register_BRepOffset_enums(py::module&);
void register_BRepOffsetAPI_enums(py::module&);
void register_BiTgte_enums(py::module&);
void register_Draft_enums(py::module&);
void register_Aspect_enums(py::module&);
void register_Font_enums(py::module&);
void register_Image_enums(py::module&);
void register_InterfaceGraphic_enums(py::module&);
void register_SelectBasics_enums(py::module&);
void register_Graphic3d_enums(py::module&);
void register_Prs3d_enums(py::module&);
void register_PrsMgr_enums(py::module&);
void register_SelectMgr_enums(py::module&);
void register_DsgPrs_enums(py::module&);
void register_Select3D_enums(py::module&);
void register_StdPrs_enums(py::module&);
void register_StdSelect_enums(py::module&);
void register_V3d_enums(py::module&);
void register_OpenGl_enums(py::module&);
void register_MeshVS_enums(py::module&);
void register_NIS_enums(py::module&);
void register_Voxel_enums(py::module&);
void register_CDM_enums(py::module&);
void register_CDF_enums(py::module&);
void register_LDOM_enums(py::module&);
void register_PCDM_enums(py::module&);
void register_UTL_enums(py::module&);
void register_TDF_enums(py::module&);
void register_TDataStd_enums(py::module&);
void register_TDocStd_enums(py::module&);
void register_AppStdL_enums(py::module&);
void register_TFunction_enums(py::module&);
void register_BinLDrivers_enums(py::module&);
void register_BinMDF_enums(py::module&);
void register_BinMDataStd_enums(py::module&);
void register_BinMDocStd_enums(py::module&);
void register_BinMFunction_enums(py::module&);
void register_BinObjMgt_enums(py::module&);
void register_AppStd_enums(py::module&);
void register_TDataXtd_enums(py::module&);
void register_TNaming_enums(py::module&);
void register_TObj_enums(py::module&);
void register_XmlLDrivers_enums(py::module&);
void register_XmlMDF_enums(py::module&);
void register_XmlMDataStd_enums(py::module&);
void register_XmlMDocStd_enums(py::module&);
void register_XmlMFunction_enums(py::module&);
void register_XmlObjMgt_enums(py::module&);
void register_StdLDrivers_enums(py::module&);
void register_StdObjMgt_enums(py::module&);
void register_StdLPersistent_enums(py::module&);
void register_BinDrivers_enums(py::module&);
void register_BinMDataXtd_enums(py::module&);
void register_BinMNaming_enums(py::module&);
void register_BinTObjDrivers_enums(py::module&);
void register_TPrsStd_enums(py::module&);
void register_XmlDrivers_enums(py::module&);
void register_XmlMDataXtd_enums(py::module&);
void register_XmlMNaming_enums(py::module&);
void register_XmlTObjDrivers_enums(py::module&);
void register_StdDrivers_enums(py::module&);
void register_StdObject_enums(py::module&);
void register_StdPersistent_enums(py::module&);
void register_StdStorage_enums(py::module&);
void register_RWStl_enums(py::module&);
void register_StlAPI_enums(py::module&);
void register_RWStepBasic_enums(py::module&);
void register_RWStepGeom_enums(py::module&);
void register_RWStepRepr_enums(py::module&);
void register_RWStepShape_enums(py::module&);
void register_RWMesh_enums(py::module&);
void register_StepBasic_enums(py::module&);
void register_StepGeom_enums(py::module&);
void register_StepRepr_enums(py::module&);
void register_StepShape_enums(py::module&);
void register_RWStepDimTol_enums(py::module&);
void register_RWStepVisual_enums(py::module&);
void register_StepDimTol_enums(py::module&);
void register_StepVisual_enums(py::module&);
void register_RWStepElement_enums(py::module&);
void register_RWStepFEA_enums(py::module&);
void register_StepElement_enums(py::module&);
void register_StepFEA_enums(py::module&);
void register_GeomToStep_enums(py::module&);
void register_RWStepAP203_enums(py::module&);
void register_RWStepAP214_enums(py::module&);
void register_RWStepAP242_enums(py::module&);
void register_STEPConstruct_enums(py::module&);
void register_STEPControl_enums(py::module&);
void register_STEPEdit_enums(py::module&);
void register_STEPSelections_enums(py::module&);
void register_StepAP203_enums(py::module&);
void register_StepAP209_enums(py::module&);
void register_StepAP214_enums(py::module&);
void register_StepAP242_enums(py::module&);
void register_StepToGeom_enums(py::module&);
void register_StepToTopoDS_enums(py::module&);
void register_TopoDSToStep_enums(py::module&);
void register_BRepToIGES_enums(py::module&);
void register_BRepToIGESBRep_enums(py::module&);
void register_Geom2dToIGES_enums(py::module&);
void register_GeomToIGES_enums(py::module&);
void register_IGESAppli_enums(py::module&);
void register_IGESBasic_enums(py::module&);
void register_IGESControl_enums(py::module&);
void register_IGESConvGeom_enums(py::module&);
void register_IGESData_enums(py::module&);
void register_IGESDefs_enums(py::module&);
void register_IGESDimen_enums(py::module&);
void register_IGESDraw_enums(py::module&);
void register_IGESFile_enums(py::module&);
void register_IGESGeom_enums(py::module&);
void register_IGESGraph_enums(py::module&);
void register_IGESSelect_enums(py::module&);
void register_IGESSolid_enums(py::module&);
void register_IGESToBRep_enums(py::module&);
void register_Interface_enums(py::module&);
void register_Transfer_enums(py::module&);
void register_StepData_enums(py::module&);
void register_XSControl_enums(py::module&);
void register_IFSelect_enums(py::module&);
void register_IFGraph_enums(py::module&);
void register_STEPCAFControl_enums(py::module&);
void register_IGESCAFControl_enums(py::module&);
void register_XCAFApp_enums(py::module&);
void register_XCAFDimTolObjects_enums(py::module&);
void register_XCAFDoc_enums(py::module&);
void register_XCAFNoteObjects_enums(py::module&);
void register_XCAFPrs_enums(py::module&);
void register_XCAFView_enums(py::module&);
void register_BinXCAFDrivers_enums(py::module&);
void register_XmlXCAFDrivers_enums(py::module&);
void register_Vrml_enums(py::module&);
void register_VrmlAPI_enums(py::module&);
void register_RWGltf_enums(py::module&);
void register_IVtk_enums(py::module&);
void register_IVtkOCC_enums(py::module&);
void register_IVtkTools_enums(py::module&);
void register_IVtkVTK_enums(py::module&);
void register_DE_enums(py::module&);
void register_IMeshTools_enums(py::module&);
void register_IMeshData_enums(py::module&);
void register_APIHeaderSection_enums(py::module&);
void register_UnitsMethods_enums(py::module&);
void register_Xw_enums(py::module&);

void register_NCollection(py::module&);
void register_AIS(py::module&);
void register_Standard(py::module&);
void register_gp(py::module&);
void register_math(py::module&);
void register_BVH(py::module&);
void register_TColgp(py::module&);
void register_OSD(py::module&);
void register_Quantity(py::module&);
void register_Storage(py::module&);
void register_FSD(py::module&);
void register_TCollection(py::module&);
void register_TColStd(py::module&);
void register_Message(py::module&);
void register_StdFail(py::module&);
void register_TShort(py::module&);
void register_Plugin(py::module&);
void register_Resource(py::module&);
void register_Units(py::module&);
void register_UnitsAPI(py::module&);
void register_TopLoc(py::module&);
void register_Poly(py::module&);
void register_Precision(py::module&);
void register_Expr(py::module&);
void register_ExprIntrp(py::module&);
void register_GeomAbs(py::module&);
void register_PLib(py::module&);
void register_BSplCLib(py::module&);
void register_BSplSLib(py::module&);
void register_Bnd(py::module&);
void register_CSLib(py::module&);
void register_Convert(py::module&);
void register_ElCLib(py::module&);
void register_ElSLib(py::module&);
void register_Adaptor2d(py::module&);
void register_Geom2d(py::module&);
void register_Geom2dAdaptor(py::module&);
void register_Geom2dEvaluator(py::module&);
void register_LProp(py::module&);
void register_Geom2dLProp(py::module&);
void register_TColGeom2d(py::module&);
void register_Adaptor3d(py::module&);
void register_AdvApprox(py::module&);
void register_GProp(py::module&);
void register_Geom(py::module&);
void register_GeomAdaptor(py::module&);
void register_GeomEvaluator(py::module&);
void register_GeomLProp(py::module&);
void register_LProp3d(py::module&);
void register_TColGeom(py::module&);
void register_TopAbs(py::module&);
void register_AdvApp2Var(py::module&);
void register_AppCont(py::module&);
void register_AppParCurves(py::module&);
void register_Approx(py::module&);
void register_AppDef(py::module&);
void register_BndLib(py::module&);
void register_CPnts(py::module&);
void register_Extrema(py::module&);
void register_FEmTool(py::module&);
void register_GC(py::module&);
void register_GCE2d(py::module&);
void register_GCPnts(py::module&);
void register_Geom2dConvert(py::module&);
void register_GeomConvert(py::module&);
void register_GeomLib(py::module&);
void register_GeomProjLib(py::module&);
void register_GeomTools(py::module&);
void register_Hermit(py::module&);
void register_IntAna(py::module&);
void register_IntAna2d(py::module&);
void register_ProjLib(py::module&);
void register_gce(py::module&);
void register_TopoDS(py::module&);
void register_BRep(py::module&);
void register_BRepAdaptor(py::module&);
void register_BRepLProp(py::module&);
void register_TopTools(py::module&);
void register_BRepTools(py::module&);
void register_BinTools(py::module&);
void register_TopExp(py::module&);
void register_AppBlend(py::module&);
void register_FairCurve(py::module&);
void register_GccAna(py::module&);
void register_GccEnt(py::module&);
void register_GccInt(py::module&);
void register_Geom2dAPI(py::module&);
void register_Geom2dGcc(py::module&);
void register_IntRes2d(py::module&);
void register_Intf(py::module&);
void register_Geom2dInt(py::module&);
void register_Geom2dHatch(py::module&);
void register_GeomAPI(py::module&);
void register_GeomFill(py::module&);
void register_GeomInt(py::module&);
void register_GeomPlate(py::module&);
void register_Hatch(py::module&);
void register_HatchGen(py::module&);
void register_IntCurve(py::module&);
void register_IntCurveSurface(py::module&);
void register_IntImp(py::module&);
void register_IntImpParGen(py::module&);
void register_IntPatch(py::module&);
void register_IntPolyh(py::module&);
void register_IntStart(py::module&);
void register_IntSurf(py::module&);
void register_Law(py::module&);
void register_LocalAnalysis(py::module&);
void register_NLPlate(py::module&);
void register_Plate(py::module&);
void register_TopClass(py::module&);
void register_TopTrans(py::module&);
void register_BRepApprox(py::module&);
void register_BRepBndLib(py::module&);
void register_BRepBuilderAPI(py::module&);
void register_BRepCheck(py::module&);
void register_BRepClass(py::module&);
void register_BRepClass3d(py::module&);
void register_BRepExtrema(py::module&);
void register_BRepGProp(py::module&);
void register_BRepIntCurveSurface(py::module&);
void register_BRepLib(py::module&);
void register_BRepMAT2d(py::module&);
void register_BRepTopAdaptor(py::module&);
void register_Bisector(py::module&);
void register_IntCurvesFace(py::module&);
void register_MAT(py::module&);
void register_MAT2d(py::module&);
void register_BRepPrim(py::module&);
void register_BRepPrimAPI(py::module&);
void register_BRepSweep(py::module&);
void register_Sweep(py::module&);
void register_ShapeAlgo(py::module&);
void register_ShapeAnalysis(py::module&);
void register_ShapeBuild(py::module&);
void register_ShapeConstruct(py::module&);
void register_ShapeCustom(py::module&);
void register_ShapeExtend(py::module&);
void register_ShapeFix(py::module&);
void register_ShapeProcess(py::module&);
void register_ShapeProcessAPI(py::module&);
void register_ShapeUpgrade(py::module&);
void register_Contap(py::module&);
void register_HLRAlgo(py::module&);
void register_HLRAppli(py::module&);
void register_HLRBRep(py::module&);
void register_HLRTopoBRep(py::module&);
void register_Intrv(py::module&);
void register_TopBas(py::module&);
void register_TopCnx(py::module&);
void register_BRepMesh(py::module&);
void register_XBRepMesh(py::module&);
void register_BOPAlgo(py::module&);
void register_BOPDS(py::module&);
void register_BOPTools(py::module&);
void register_BRepAlgoAPI(py::module&);
void register_IntTools(py::module&);
void register_BRepAlgo(py::module&);
void register_BRepFill(py::module&);
void register_BRepProj(py::module&);
void register_TopOpeBRep(py::module&);
void register_TopOpeBRepBuild(py::module&);
void register_TopOpeBRepDS(py::module&);
void register_TopOpeBRepTool(py::module&);
void register_BRepFeat(py::module&);
void register_LocOpe(py::module&);
void register_Blend(py::module&);
void register_BRepBlend(py::module&);
void register_BRepFilletAPI(py::module&);
void register_BlendFunc(py::module&);
void register_ChFi2d(py::module&);
void register_ChFi3d(py::module&);
void register_ChFiDS(py::module&);
void register_FilletSurf(py::module&);
void register_BRepOffset(py::module&);
void register_BRepOffsetAPI(py::module&);
void register_BiTgte(py::module&);
void register_Draft(py::module&);
void register_Aspect(py::module&);
void register_Font(py::module&);
void register_Image(py::module&);
void register_InterfaceGraphic(py::module&);
void register_SelectBasics(py::module&);
void register_Graphic3d(py::module&);
void register_Prs3d(py::module&);
void register_PrsMgr(py::module&);
void register_SelectMgr(py::module&);
void register_DsgPrs(py::module&);
void register_Select3D(py::module&);
void register_StdPrs(py::module&);
void register_StdSelect(py::module&);
void register_V3d(py::module&);
void register_OpenGl(py::module&);
void register_MeshVS(py::module&);
void register_NIS(py::module&);
void register_Voxel(py::module&);
void register_CDM(py::module&);
void register_CDF(py::module&);
void register_LDOM(py::module&);
void register_PCDM(py::module&);
void register_UTL(py::module&);
void register_TDF(py::module&);
void register_TDataStd(py::module&);
void register_TDocStd(py::module&);
void register_AppStdL(py::module&);
void register_TFunction(py::module&);
void register_BinLDrivers(py::module&);
void register_BinMDF(py::module&);
void register_BinMDataStd(py::module&);
void register_BinMDocStd(py::module&);
void register_BinMFunction(py::module&);
void register_BinObjMgt(py::module&);
void register_AppStd(py::module&);
void register_TDataXtd(py::module&);
void register_TNaming(py::module&);
void register_TObj(py::module&);
void register_XmlLDrivers(py::module&);
void register_XmlMDF(py::module&);
void register_XmlMDataStd(py::module&);
void register_XmlMDocStd(py::module&);
void register_XmlMFunction(py::module&);
void register_XmlObjMgt(py::module&);
void register_StdLDrivers(py::module&);
void register_StdObjMgt(py::module&);
void register_StdLPersistent(py::module&);
void register_BinDrivers(py::module&);
void register_BinMDataXtd(py::module&);
void register_BinMNaming(py::module&);
void register_BinTObjDrivers(py::module&);
void register_TPrsStd(py::module&);
void register_XmlDrivers(py::module&);
void register_XmlMDataXtd(py::module&);
void register_XmlMNaming(py::module&);
void register_XmlTObjDrivers(py::module&);
void register_StdDrivers(py::module&);
void register_StdObject(py::module&);
void register_StdPersistent(py::module&);
void register_StdStorage(py::module&);
void register_RWStl(py::module&);
void register_StlAPI(py::module&);
void register_RWStepBasic(py::module&);
void register_RWStepGeom(py::module&);
void register_RWStepRepr(py::module&);
void register_RWStepShape(py::module&);
void register_RWMesh(py::module&);
void register_StepBasic(py::module&);
void register_StepGeom(py::module&);
void register_StepRepr(py::module&);
void register_StepShape(py::module&);
void register_RWStepDimTol(py::module&);
void register_RWStepVisual(py::module&);
void register_StepDimTol(py::module&);
void register_StepVisual(py::module&);
void register_RWStepElement(py::module&);
void register_RWStepFEA(py::module&);
void register_StepElement(py::module&);
void register_StepFEA(py::module&);
void register_GeomToStep(py::module&);
void register_RWStepAP203(py::module&);
void register_RWStepAP214(py::module&);
void register_RWStepAP242(py::module&);
void register_STEPConstruct(py::module&);
void register_STEPControl(py::module&);
void register_STEPEdit(py::module&);
void register_STEPSelections(py::module&);
void register_StepAP203(py::module&);
void register_StepAP209(py::module&);
void register_StepAP214(py::module&);
void register_StepAP242(py::module&);
void register_StepToGeom(py::module&);
void register_StepToTopoDS(py::module&);
void register_TopoDSToStep(py::module&);
void register_BRepToIGES(py::module&);
void register_BRepToIGESBRep(py::module&);
void register_Geom2dToIGES(py::module&);
void register_GeomToIGES(py::module&);
void register_IGESAppli(py::module&);
void register_IGESBasic(py::module&);
void register_IGESControl(py::module&);
void register_IGESConvGeom(py::module&);
void register_IGESData(py::module&);
void register_IGESDefs(py::module&);
void register_IGESDimen(py::module&);
void register_IGESDraw(py::module&);
void register_IGESFile(py::module&);
void register_IGESGeom(py::module&);
void register_IGESGraph(py::module&);
void register_IGESSelect(py::module&);
void register_IGESSolid(py::module&);
void register_IGESToBRep(py::module&);
void register_Interface(py::module&);
void register_Transfer(py::module&);
void register_StepData(py::module&);
void register_XSControl(py::module&);
void register_IFSelect(py::module&);
void register_IFGraph(py::module&);
void register_STEPCAFControl(py::module&);
void register_IGESCAFControl(py::module&);
void register_XCAFApp(py::module&);
void register_XCAFDimTolObjects(py::module&);
void register_XCAFDoc(py::module&);
void register_XCAFNoteObjects(py::module&);
void register_XCAFPrs(py::module&);
void register_XCAFView(py::module&);
void register_BinXCAFDrivers(py::module&);
void register_XmlXCAFDrivers(py::module&);
void register_Vrml(py::module&);
void register_VrmlAPI(py::module&);
void register_RWGltf(py::module&);
void register_IVtk(py::module&);
void register_IVtkOCC(py::module&);
void register_IVtkTools(py::module&);
void register_IVtkVTK(py::module&);
void register_DE(py::module&);
void register_IMeshTools(py::module&);
void register_IMeshData(py::module&);
void register_APIHeaderSection(py::module&);
void register_UnitsMethods(py::module&);
void register_Xw(py::module&);

// main module definiiton
PYBIND11_MODULE(OCP, m) {

// register submodules

    register_AdvApprox_enums(m);
    register_AppBlend_enums(m);
    register_AppCont_enums(m);
    register_BRepBndLib_enums(m);
    register_BRepIntCurveSurface_enums(m);
    register_BRepLProp_enums(m);
    register_BRepLib_enums(m);
    register_BRepPrim_enums(m);
    register_BRepProj_enums(m);
    register_BRepSweep_enums(m);
    register_BRepToIGES_enums(m);
    register_BinTools_enums(m);
    register_BndLib_enums(m);
    register_ChFi2d_enums(m);
    register_ElCLib_enums(m);
    register_ElSLib_enums(m);
    register_GC_enums(m);
    register_GCE2d_enums(m);
    register_GProp_enums(m);
    register_GccAna_enums(m);
    register_GccEnt_enums(m);
    register_Geom2dAPI_enums(m);
    register_Geom2dToIGES_enums(m);
    register_GeomAPI_enums(m);
    register_GeomAbs_enums(m);
    register_GeomLProp_enums(m);
    register_GeomProjLib_enums(m);
    register_GeomToIGES_enums(m);
    register_GeomToStep_enums(m);
    register_HLRAppli_enums(m);
    register_Hermit_enums(m);
    register_IGESConvGeom_enums(m);
    register_IGESFile_enums(m);
    register_IVtkTools_enums(m);
    register_IntAna2d_enums(m);
    register_IntImp_enums(m);
    register_IntImpParGen_enums(m);
    register_InterfaceGraphic_enums(m);
    register_LDOM_enums(m);
    register_LProp3d_enums(m);
    register_LocalAnalysis_enums(m);
    register_NIS_enums(m);
    register_Precision_enums(m);
    register_RWStepAP203_enums(m);
    register_RWStepAP214_enums(m);
    register_RWStepAP242_enums(m);
    register_RWStepBasic_enums(m);
    register_RWStepDimTol_enums(m);
    register_RWStepElement_enums(m);
    register_RWStepFEA_enums(m);
    register_RWStepGeom_enums(m);
    register_RWStepRepr_enums(m);
    register_RWStepShape_enums(m);
    register_RWStepVisual_enums(m);
    register_SelectBasics_enums(m);
    register_ShapeProcessAPI_enums(m);
    register_Standard_enums(m);
    register_StdFail_enums(m);
    register_StdObject_enums(m);
    register_StepToGeom_enums(m);
    register_StlAPI_enums(m);
    register_Sweep_enums(m);
    register_TopAbs_enums(m);
    register_TopClass_enums(m);
    register_TopCnx_enums(m);
    register_TopExp_enums(m);
    register_TopTrans_enums(m);
    register_TopoDSToStep_enums(m);
    register_UTL_enums(m);
    register_UnitsAPI_enums(m);
    register_UnitsMethods_enums(m);
    register_Voxel_enums(m);
    register_XBRepMesh_enums(m);
    register_XmlObjMgt_enums(m);
    register_gce_enums(m);
    register_gp_enums(m);
    register_math_enums(m);
    register_Adaptor2d_enums(m);
    register_Adaptor3d_enums(m);
    register_BRepAlgo_enums(m);
    register_BRepApprox_enums(m);
    register_BRepGProp_enums(m);
    register_BRepToIGESBRep_enums(m);
    register_BSplCLib_enums(m);
    register_BSplSLib_enums(m);
    register_BVH_enums(m);
    register_BinObjMgt_enums(m);
    register_Bnd_enums(m);
    register_CPnts_enums(m);
    register_CSLib_enums(m);
    register_ChFi3d_enums(m);
    register_FairCurve_enums(m);
    register_GCPnts_enums(m);
    register_GccInt_enums(m);
    register_Geom2d_enums(m);
    register_Geom2dEvaluator_enums(m);
    register_Geom2dGcc_enums(m);
    register_GeomConvert_enums(m);
    register_GeomEvaluator_enums(m);
    register_GeomLib_enums(m);
    register_GeomTools_enums(m);
    register_IMeshData_enums(m);
    register_IntCurvesFace_enums(m);
    register_IntStart_enums(m);
    register_NCollection_enums(m);
    register_OSD_enums(m);
    register_PLib_enums(m);
    register_Quantity_enums(m);
    register_RWStl_enums(m);
    register_ShapeAlgo_enums(m);
    register_ShapeProcess_enums(m);
    register_ShapeUpgrade_enums(m);
    register_StdObjMgt_enums(m);
    register_StdPersistent_enums(m);
    register_TCollection_enums(m);
    register_Vrml_enums(m);
    register_XCAFNoteObjects_enums(m);
    register_XCAFView_enums(m);
    register_AdvApp2Var_enums(m);
    register_AppParCurves_enums(m);
    register_Approx_enums(m);
    register_Aspect_enums(m);
    register_BOPDS_enums(m);
    register_BOPTools_enums(m);
    register_BRepBuilderAPI_enums(m);
    register_BRepCheck_enums(m);
    register_BRepClass3d_enums(m);
    register_BRepExtrema_enums(m);
    register_BRepMAT2d_enums(m);
    register_BRepTopAdaptor_enums(m);
    register_BiTgte_enums(m);
    register_BinMDF_enums(m);
    register_Blend_enums(m);
    register_CDM_enums(m);
    register_ChFiDS_enums(m);
    register_Contap_enums(m);
    register_Convert_enums(m);
    register_DE_enums(m);
    register_Expr_enums(m);
    register_ExprIntrp_enums(m);
    register_Extrema_enums(m);
    register_FEmTool_enums(m);
    register_FilletSurf_enums(m);
    register_Font_enums(m);
    register_Geom_enums(m);
    register_Geom2dAdaptor_enums(m);
    register_Geom2dConvert_enums(m);
    register_GeomAdaptor_enums(m);
    register_GeomInt_enums(m);
    register_Graphic3d_enums(m);
    register_HLRAlgo_enums(m);
    register_HLRTopoBRep_enums(m);
    register_Hatch_enums(m);
    register_HatchGen_enums(m);
    register_IVtk_enums(m);
    register_Image_enums(m);
    register_IntAna_enums(m);
    register_IntPolyh_enums(m);
    register_IntRes2d_enums(m);
    register_IntSurf_enums(m);
    register_IntTools_enums(m);
    register_Interface_enums(m);
    register_Intf_enums(m);
    register_Intrv_enums(m);
    register_LProp_enums(m);
    register_Law_enums(m);
    register_LocOpe_enums(m);
    register_MAT_enums(m);
    register_MAT2d_enums(m);
    register_Message_enums(m);
    register_NLPlate_enums(m);
    register_PCDM_enums(m);
    register_Plate_enums(m);
    register_Plugin_enums(m);
    register_Poly_enums(m);
    register_ProjLib_enums(m);
    register_Resource_enums(m);
    register_STEPConstruct_enums(m);
    register_ShapeAnalysis_enums(m);
    register_ShapeFix_enums(m);
    register_StdLPersistent_enums(m);
    register_StdStorage_enums(m);
    register_StepToTopoDS_enums(m);
    register_Storage_enums(m);
    register_TColGeom_enums(m);
    register_TColGeom2d_enums(m);
    register_TColStd_enums(m);
    register_TColgp_enums(m);
    register_TDF_enums(m);
    register_TShort_enums(m);
    register_TopBas_enums(m);
    register_TopLoc_enums(m);
    register_TopOpeBRep_enums(m);
    register_TopOpeBRepBuild_enums(m);
    register_TopOpeBRepDS_enums(m);
    register_TopOpeBRepTool_enums(m);
    register_TopTools_enums(m);
    register_Units_enums(m);
    register_XCAFDimTolObjects_enums(m);
    register_XmlMDF_enums(m);
    register_AppDef_enums(m);
    register_BRepAdaptor_enums(m);
    register_BRepBlend_enums(m);
    register_BRepFilletAPI_enums(m);
    register_BRepPrimAPI_enums(m);
    register_BRepTools_enums(m);
    register_BinLDrivers_enums(m);
    register_BinMDataStd_enums(m);
    register_BinMDataXtd_enums(m);
    register_BinMDocStd_enums(m);
    register_BinMFunction_enums(m);
    register_BinMNaming_enums(m);
    register_Bisector_enums(m);
    register_BlendFunc_enums(m);
    register_CDF_enums(m);
    register_FSD_enums(m);
    register_Geom2dInt_enums(m);
    register_Geom2dLProp_enums(m);
    register_GeomFill_enums(m);
    register_GeomPlate_enums(m);
    register_IFGraph_enums(m);
    register_IFSelect_enums(m);
    register_IGESData_enums(m);
    register_IMeshTools_enums(m);
    register_IVtkVTK_enums(m);
    register_IntCurve_enums(m);
    register_IntCurveSurface_enums(m);
    register_IntPatch_enums(m);
    register_OpenGl_enums(m);
    register_Prs3d_enums(m);
    register_PrsMgr_enums(m);
    register_RWMesh_enums(m);
    register_Select3D_enums(m);
    register_ShapeConstruct_enums(m);
    register_ShapeExtend_enums(m);
    register_StdLDrivers_enums(m);
    register_StepAP209_enums(m);
    register_StepData_enums(m);
    register_TDataStd_enums(m);
    register_TFunction_enums(m);
    register_TNaming_enums(m);
    register_TPrsStd_enums(m);
    register_TopoDS_enums(m);
    register_Transfer_enums(m);
    register_V3d_enums(m);
    register_XmlLDrivers_enums(m);
    register_XmlMDataStd_enums(m);
    register_XmlMDataXtd_enums(m);
    register_XmlMDocStd_enums(m);
    register_XmlMFunction_enums(m);
    register_XmlMNaming_enums(m);
    register_Xw_enums(m);
    register_APIHeaderSection_enums(m);
    register_BOPAlgo_enums(m);
    register_BRep_enums(m);
    register_BRepClass_enums(m);
    register_BRepFill_enums(m);
    register_BRepMesh_enums(m);
    register_BRepOffset_enums(m);
    register_BRepOffsetAPI_enums(m);
    register_BinDrivers_enums(m);
    register_BinTObjDrivers_enums(m);
    register_Draft_enums(m);
    register_DsgPrs_enums(m);
    register_Geom2dHatch_enums(m);
    register_HLRBRep_enums(m);
    register_IGESAppli_enums(m);
    register_IGESBasic_enums(m);
    register_IGESDefs_enums(m);
    register_IGESDimen_enums(m);
    register_IGESDraw_enums(m);
    register_IGESGeom_enums(m);
    register_IGESGraph_enums(m);
    register_IGESSelect_enums(m);
    register_IGESSolid_enums(m);
    register_IGESToBRep_enums(m);
    register_RWGltf_enums(m);
    register_STEPEdit_enums(m);
    register_SelectMgr_enums(m);
    register_ShapeBuild_enums(m);
    register_ShapeCustom_enums(m);
    register_StdDrivers_enums(m);
    register_StdPrs_enums(m);
    register_StepAP242_enums(m);
    register_StepBasic_enums(m);
    register_StepElement_enums(m);
    register_TDataXtd_enums(m);
    register_TDocStd_enums(m);
    register_VrmlAPI_enums(m);
    register_XCAFDoc_enums(m);
    register_XSControl_enums(m);
    register_XmlDrivers_enums(m);
    register_XmlTObjDrivers_enums(m);
    register_AIS_enums(m);
    register_AppStd_enums(m);
    register_AppStdL_enums(m);
    register_BRepAlgoAPI_enums(m);
    register_BRepFeat_enums(m);
    register_BinXCAFDrivers_enums(m);
    register_IGESControl_enums(m);
    register_IVtkOCC_enums(m);
    register_STEPControl_enums(m);
    register_STEPSelections_enums(m);
    register_StdSelect_enums(m);
    register_StepAP203_enums(m);
    register_StepRepr_enums(m);
    register_TObj_enums(m);
    register_XCAFApp_enums(m);
    register_XmlXCAFDrivers_enums(m);
    register_IGESCAFControl_enums(m);
    register_MeshVS_enums(m);
    register_STEPCAFControl_enums(m);
    register_StepDimTol_enums(m);
    register_StepGeom_enums(m);
    register_XCAFPrs_enums(m);
    register_StepFEA_enums(m);
    register_StepShape_enums(m);
    register_StepVisual_enums(m);
    register_StepAP214_enums(m);

    register_AdvApprox(m);
    register_AppBlend(m);
    register_AppCont(m);
    register_BRepBndLib(m);
    register_BRepIntCurveSurface(m);
    register_BRepLProp(m);
    register_BRepLib(m);
    register_BRepPrim(m);
    register_BRepProj(m);
    register_BRepSweep(m);
    register_BRepToIGES(m);
    register_BinTools(m);
    register_BndLib(m);
    register_ChFi2d(m);
    register_ElCLib(m);
    register_ElSLib(m);
    register_GC(m);
    register_GCE2d(m);
    register_GProp(m);
    register_GccAna(m);
    register_GccEnt(m);
    register_Geom2dAPI(m);
    register_Geom2dToIGES(m);
    register_GeomAPI(m);
    register_GeomAbs(m);
    register_GeomLProp(m);
    register_GeomProjLib(m);
    register_GeomToIGES(m);
    register_GeomToStep(m);
    register_HLRAppli(m);
    register_Hermit(m);
    register_IGESConvGeom(m);
    register_IGESFile(m);
    register_IVtkTools(m);
    register_IntAna2d(m);
    register_IntImp(m);
    register_IntImpParGen(m);
    register_InterfaceGraphic(m);
    register_LDOM(m);
    register_LProp3d(m);
    register_LocalAnalysis(m);
    register_NIS(m);
    register_Precision(m);
    register_RWStepAP203(m);
    register_RWStepAP214(m);
    register_RWStepAP242(m);
    register_RWStepBasic(m);
    register_RWStepDimTol(m);
    register_RWStepElement(m);
    register_RWStepFEA(m);
    register_RWStepGeom(m);
    register_RWStepRepr(m);
    register_RWStepShape(m);
    register_RWStepVisual(m);
    register_SelectBasics(m);
    register_ShapeProcessAPI(m);
    register_Standard(m);
    register_StdFail(m);
    register_StdObject(m);
    register_StepToGeom(m);
    register_StlAPI(m);
    register_Sweep(m);
    register_TopAbs(m);
    register_TopClass(m);
    register_TopCnx(m);
    register_TopExp(m);
    register_TopTrans(m);
    register_TopoDSToStep(m);
    register_UTL(m);
    register_UnitsAPI(m);
    register_UnitsMethods(m);
    register_Voxel(m);
    register_XBRepMesh(m);
    register_XmlObjMgt(m);
    register_gce(m);
    register_gp(m);
    register_math(m);
    register_Adaptor2d(m);
    register_Adaptor3d(m);
    register_BRepAlgo(m);
    register_BRepApprox(m);
    register_BRepGProp(m);
    register_BRepToIGESBRep(m);
    register_BSplCLib(m);
    register_BSplSLib(m);
    register_BVH(m);
    register_BinObjMgt(m);
    register_Bnd(m);
    register_CPnts(m);
    register_CSLib(m);
    register_ChFi3d(m);
    register_FairCurve(m);
    register_GCPnts(m);
    register_GccInt(m);
    register_Geom2d(m);
    register_Geom2dEvaluator(m);
    register_Geom2dGcc(m);
    register_GeomConvert(m);
    register_GeomEvaluator(m);
    register_GeomLib(m);
    register_GeomTools(m);
    register_IMeshData(m);
    register_IntCurvesFace(m);
    register_IntStart(m);
    register_NCollection(m);
    register_OSD(m);
    register_PLib(m);
    register_Quantity(m);
    register_RWStl(m);
    register_ShapeAlgo(m);
    register_ShapeProcess(m);
    register_ShapeUpgrade(m);
    register_StdObjMgt(m);
    register_StdPersistent(m);
    register_TCollection(m);
    register_Vrml(m);
    register_XCAFNoteObjects(m);
    register_XCAFView(m);
    register_AdvApp2Var(m);
    register_AppParCurves(m);
    register_Approx(m);
    register_Aspect(m);
    register_BOPDS(m);
    register_BOPTools(m);
    register_BRepBuilderAPI(m);
    register_BRepCheck(m);
    register_BRepClass3d(m);
    register_BRepExtrema(m);
    register_BRepMAT2d(m);
    register_BRepTopAdaptor(m);
    register_BiTgte(m);
    register_BinMDF(m);
    register_Blend(m);
    register_CDM(m);
    register_ChFiDS(m);
    register_Contap(m);
    register_Convert(m);
    register_DE(m);
    register_Expr(m);
    register_ExprIntrp(m);
    register_Extrema(m);
    register_FEmTool(m);
    register_FilletSurf(m);
    register_Font(m);
    register_Geom(m);
    register_Geom2dAdaptor(m);
    register_Geom2dConvert(m);
    register_GeomAdaptor(m);
    register_GeomInt(m);
    register_Graphic3d(m);
    register_HLRAlgo(m);
    register_HLRTopoBRep(m);
    register_Hatch(m);
    register_HatchGen(m);
    register_IVtk(m);
    register_Image(m);
    register_IntAna(m);
    register_IntPolyh(m);
    register_IntRes2d(m);
    register_IntSurf(m);
    register_IntTools(m);
    register_Interface(m);
    register_Intf(m);
    register_Intrv(m);
    register_LProp(m);
    register_Law(m);
    register_LocOpe(m);
    register_MAT(m);
    register_MAT2d(m);
    register_Message(m);
    register_NLPlate(m);
    register_PCDM(m);
    register_Plate(m);
    register_Plugin(m);
    register_Poly(m);
    register_ProjLib(m);
    register_Resource(m);
    register_STEPConstruct(m);
    register_ShapeAnalysis(m);
    register_ShapeFix(m);
    register_StdLPersistent(m);
    register_StdStorage(m);
    register_StepToTopoDS(m);
    register_Storage(m);
    register_TColGeom(m);
    register_TColGeom2d(m);
    register_TColStd(m);
    register_TColgp(m);
    register_TDF(m);
    register_TShort(m);
    register_TopBas(m);
    register_TopLoc(m);
    register_TopOpeBRep(m);
    register_TopOpeBRepBuild(m);
    register_TopOpeBRepDS(m);
    register_TopOpeBRepTool(m);
    register_TopTools(m);
    register_Units(m);
    register_XCAFDimTolObjects(m);
    register_XmlMDF(m);
    register_AppDef(m);
    register_BRepAdaptor(m);
    register_BRepBlend(m);
    register_BRepFilletAPI(m);
    register_BRepPrimAPI(m);
    register_BRepTools(m);
    register_BinLDrivers(m);
    register_BinMDataStd(m);
    register_BinMDataXtd(m);
    register_BinMDocStd(m);
    register_BinMFunction(m);
    register_BinMNaming(m);
    register_Bisector(m);
    register_BlendFunc(m);
    register_CDF(m);
    register_FSD(m);
    register_Geom2dInt(m);
    register_Geom2dLProp(m);
    register_GeomFill(m);
    register_GeomPlate(m);
    register_IFGraph(m);
    register_IFSelect(m);
    register_IGESData(m);
    register_IMeshTools(m);
    register_IVtkVTK(m);
    register_IntCurve(m);
    register_IntCurveSurface(m);
    register_IntPatch(m);
    register_OpenGl(m);
    register_Prs3d(m);
    register_PrsMgr(m);
    register_RWMesh(m);
    register_Select3D(m);
    register_ShapeConstruct(m);
    register_ShapeExtend(m);
    register_StdLDrivers(m);
    register_StepAP209(m);
    register_StepData(m);
    register_TDataStd(m);
    register_TFunction(m);
    register_TNaming(m);
    register_TPrsStd(m);
    register_TopoDS(m);
    register_Transfer(m);
    register_V3d(m);
    register_XmlLDrivers(m);
    register_XmlMDataStd(m);
    register_XmlMDataXtd(m);
    register_XmlMDocStd(m);
    register_XmlMFunction(m);
    register_XmlMNaming(m);
    register_Xw(m);
    register_APIHeaderSection(m);
    register_BOPAlgo(m);
    register_BRep(m);
    register_BRepClass(m);
    register_BRepFill(m);
    register_BRepMesh(m);
    register_BRepOffset(m);
    register_BRepOffsetAPI(m);
    register_BinDrivers(m);
    register_BinTObjDrivers(m);
    register_Draft(m);
    register_DsgPrs(m);
    register_Geom2dHatch(m);
    register_HLRBRep(m);
    register_IGESAppli(m);
    register_IGESBasic(m);
    register_IGESDefs(m);
    register_IGESDimen(m);
    register_IGESDraw(m);
    register_IGESGeom(m);
    register_IGESGraph(m);
    register_IGESSelect(m);
    register_IGESSolid(m);
    register_IGESToBRep(m);
    register_RWGltf(m);
    register_STEPEdit(m);
    register_SelectMgr(m);
    register_ShapeBuild(m);
    register_ShapeCustom(m);
    register_StdDrivers(m);
    register_StdPrs(m);
    register_StepAP242(m);
    register_StepBasic(m);
    register_StepElement(m);
    register_TDataXtd(m);
    register_TDocStd(m);
    register_VrmlAPI(m);
    register_XCAFDoc(m);
    register_XSControl(m);
    register_XmlDrivers(m);
    register_XmlTObjDrivers(m);
    register_AIS(m);
    register_AppStd(m);
    register_AppStdL(m);
    register_BRepAlgoAPI(m);
    register_BRepFeat(m);
    register_BinXCAFDrivers(m);
    register_IGESControl(m);
    register_IVtkOCC(m);
    register_STEPControl(m);
    register_STEPSelections(m);
    register_StdSelect(m);
    register_StepAP203(m);
    register_StepRepr(m);
    register_TObj(m);
    register_XCAFApp(m);
    register_XmlXCAFDrivers(m);
    register_IGESCAFControl(m);
    register_MeshVS(m);
    register_STEPCAFControl(m);
    register_StepDimTol(m);
    register_StepGeom(m);
    register_XCAFPrs(m);
    register_StepFEA(m);
    register_StepShape(m);
    register_StepVisual(m);
    register_StepAP214(m);

// Add attributes if present

    m.attr("__version__") = py::cast("7.9.3.1");

}